@@ -54,7 +54,7 @@ LONRBGLSS <- function(y,e,X,g,w,z,k,quant,max.steps,sparse, structure){
     )
   }
 
-  out = list( GS.alpha = fit$GS.alpha, GS.beta = fit$GS.beta,
+  out = list(GS.alpha = fit$GS.alpha[,1:(q-o)], GS.gamma = fit$GS.alpha[,-(1:(q-o))], GS.beta = fit$GS.beta,
               GS.eta = fit$GS.eta, GS.ata = fit$GS.ata)
   out
 
